print.noia.linear <-
function (x, ...) 
{
    print.noia.common(x, ...)
}
